# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: identity/app_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from union.internal.identity import app_payload_pb2 as identity_dot_app__payload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aidentity/app_service.proto\x12\x11\x63loudidl.identity\x1a\x1cgoogle/api/annotations.proto\x1a\x1aidentity/app_payload.proto2\xda\x04\n\x0b\x41ppsService\x12q\n\x06\x43reate\x12#.cloudidl.identity.CreateAppRequest\x1a$.cloudidl.identity.CreateAppResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/oauth_app/api/v1:\x01*\x12q\n\x03Get\x12 .cloudidl.identity.GetAppRequest\x1a!.cloudidl.identity.GetAppResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/oauth_app/api/v1/{client_id}\x12}\n\x06Update\x12#.cloudidl.identity.UpdateAppRequest\x1a$.cloudidl.identity.UpdateAppResponse\"(\x82\xd3\xe4\x93\x02\"\x1a\x1d/oauth_app/api/v1/{client_id}:\x01*\x12z\n\x06\x44\x65lete\x12#.cloudidl.identity.DeleteAppRequest\x1a$.cloudidl.identity.DeleteAppResponse\"%\x82\xd3\xe4\x93\x02\x1f*\x1d/oauth_app/api/v1/{client_id}\x12j\n\x04List\x12\".cloudidl.identity.ListAppsRequest\x1a#.cloudidl.identity.ListAppsResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/oauth_app/api/v1B\xbc\x01\n\x15\x63om.cloudidl.identityB\x0f\x41ppServiceProtoH\x02P\x01Z+github.com/unionai/cloud/gen/pb-go/identity\xa2\x02\x03\x43IX\xaa\x02\x11\x43loudidl.Identity\xca\x02\x11\x43loudidl\\Identity\xe2\x02\x1d\x43loudidl\\Identity\\GPBMetadata\xea\x02\x12\x43loudidl::Identityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'identity.app_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.cloudidl.identityB\017AppServiceProtoH\002P\001Z+github.com/unionai/cloud/gen/pb-go/identity\242\002\003CIX\252\002\021Cloudidl.Identity\312\002\021Cloudidl\\Identity\342\002\035Cloudidl\\Identity\\GPBMetadata\352\002\022Cloudidl::Identity'
  _APPSSERVICE.methods_by_name['Create']._options = None
  _APPSSERVICE.methods_by_name['Create']._serialized_options = b'\202\323\344\223\002\026\"\021/oauth_app/api/v1:\001*'
  _APPSSERVICE.methods_by_name['Get']._options = None
  _APPSSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\037\022\035/oauth_app/api/v1/{client_id}'
  _APPSSERVICE.methods_by_name['Update']._options = None
  _APPSSERVICE.methods_by_name['Update']._serialized_options = b'\202\323\344\223\002\"\032\035/oauth_app/api/v1/{client_id}:\001*'
  _APPSSERVICE.methods_by_name['Delete']._options = None
  _APPSSERVICE.methods_by_name['Delete']._serialized_options = b'\202\323\344\223\002\037*\035/oauth_app/api/v1/{client_id}'
  _APPSSERVICE.methods_by_name['List']._options = None
  _APPSSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\023\022\021/oauth_app/api/v1'
  _globals['_APPSSERVICE']._serialized_start=108
  _globals['_APPSSERVICE']._serialized_end=710
# @@protoc_insertion_point(module_scope)
