# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: identity/app_payload.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from union.internal.common import list_pb2 as common_dot_list__pb2
from union.internal.identity import app_definition_pb2 as identity_dot_app__definition__pb2
from union.internal.identity import enums_pb2 as identity_dot_enums__pb2
from union.internal.validate.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aidentity/app_payload.proto\x12\x11\x63loudidl.identity\x1a\x11\x63ommon/list.proto\x1a\x1didentity/app_definition.proto\x1a\x14identity/enums.proto\x1a\x17validate/validate.proto\"\xd5\x05\n\x10\x43reateAppRequest\x12\"\n\x0corganization\x18\x01 \x01(\tR\x0corganization\x12\x1b\n\tclient_id\x18\x02 \x01(\tR\x08\x63lientId\x12#\n\rredirect_uris\x18\x04 \x03(\tR\x0credirectUris\x12G\n\x0eresponse_types\x18\x05 \x03(\x0e\x32 .cloudidl.identity.ResponseTypesR\rresponseTypes\x12>\n\x0bgrant_types\x18\x06 \x03(\x0e\x32\x1d.cloudidl.identity.GrantTypesR\ngrantTypes\x12M\n\x10\x61pplication_type\x18\x07 \x01(\x0e\x32\".cloudidl.identity.ApplicationTypeR\x0f\x61pplicationType\x12\x1a\n\x08\x63ontacts\x18\x08 \x03(\tR\x08\x63ontacts\x12(\n\x0b\x63lient_name\x18\t \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\nclientName\x12\x19\n\x08logo_uri\x18\n \x01(\tR\x07logoUri\x12\x1d\n\nclient_uri\x18\x0b \x01(\tR\tclientUri\x12\x1d\n\npolicy_uri\x18\x0c \x01(\tR\tpolicyUri\x12\x17\n\x07tos_uri\x18\r \x01(\tR\x06tosUri\x12\x19\n\x08jwks_uri\x18\x0e \x01(\tR\x07jwksUri\x12g\n\x1atoken_endpoint_auth_method\x18\x0f \x01(\x0e\x32*.cloudidl.identity.TokenEndpointAuthMethodR\x17tokenEndpointAuthMethod\x12G\n\x0e\x63onsent_method\x18\x10 \x01(\x0e\x32 .cloudidl.identity.ConsentMethodR\rconsentMethod\"=\n\x11\x43reateAppResponse\x12(\n\x03\x61pp\x18\x01 \x01(\x0b\x32\x16.cloudidl.identity.AppR\x03\x61pp\"Y\n\rGetAppRequest\x12\"\n\x0corganization\x18\x01 \x01(\tR\x0corganization\x12$\n\tclient_id\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08\x63lientId\":\n\x0eGetAppResponse\x12(\n\x03\x61pp\x18\x01 \x01(\x0b\x32\x16.cloudidl.identity.AppR\x03\x61pp\"\x8c\x05\n\x10UpdateAppRequest\x12\"\n\x0corganization\x18\x01 \x01(\tR\x0corganization\x12$\n\tclient_id\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08\x63lientId\x12#\n\rredirect_uris\x18\x04 \x03(\tR\x0credirectUris\x12G\n\x0eresponse_types\x18\x05 \x03(\x0e\x32 .cloudidl.identity.ResponseTypesR\rresponseTypes\x12>\n\x0bgrant_types\x18\x06 \x03(\x0e\x32\x1d.cloudidl.identity.GrantTypesR\ngrantTypes\x12M\n\x10\x61pplication_type\x18\x07 \x01(\x0e\x32\".cloudidl.identity.ApplicationTypeR\x0f\x61pplicationType\x12\x1a\n\x08\x63ontacts\x18\x08 \x03(\tR\x08\x63ontacts\x12\x1f\n\x0b\x63lient_name\x18\t \x01(\tR\nclientName\x12\x19\n\x08logo_uri\x18\n \x01(\tR\x07logoUri\x12\x1d\n\nclient_uri\x18\x0b \x01(\tR\tclientUri\x12\x1d\n\npolicy_uri\x18\x0c \x01(\tR\tpolicyUri\x12\x17\n\x07tos_uri\x18\r \x01(\tR\x06tosUri\x12\x19\n\x08jwks_uri\x18\x0e \x01(\tR\x07jwksUri\x12g\n\x1atoken_endpoint_auth_method\x18\x0f \x01(\x0e\x32*.cloudidl.identity.TokenEndpointAuthMethodR\x17tokenEndpointAuthMethod\"=\n\x11UpdateAppResponse\x12(\n\x03\x61pp\x18\x01 \x01(\x0b\x32\x16.cloudidl.identity.AppR\x03\x61pp\"\\\n\x10\x44\x65leteAppRequest\x12\"\n\x0corganization\x18\x01 \x01(\tR\x0corganization\x12$\n\tclient_id\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08\x63lientId\"\x13\n\x11\x44\x65leteAppResponse\"m\n\x0fListAppsRequest\x12\"\n\x0corganization\x18\x01 \x01(\tR\x0corganization\x12\x36\n\x07request\x18\x02 \x01(\x0b\x32\x1c.cloudidl.common.ListRequestR\x07request\"T\n\x10ListAppsResponse\x12*\n\x04\x61pps\x18\x01 \x03(\x0b\x32\x16.cloudidl.identity.AppR\x04\x61pps\x12\x14\n\x05token\x18\x02 \x01(\tR\x05tokenB\xbc\x01\n\x15\x63om.cloudidl.identityB\x0f\x41ppPayloadProtoH\x02P\x01Z+github.com/unionai/cloud/gen/pb-go/identity\xa2\x02\x03\x43IX\xaa\x02\x11\x43loudidl.Identity\xca\x02\x11\x43loudidl\\Identity\xe2\x02\x1d\x43loudidl\\Identity\\GPBMetadata\xea\x02\x12\x43loudidl::Identityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'identity.app_payload_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.cloudidl.identityB\017AppPayloadProtoH\002P\001Z+github.com/unionai/cloud/gen/pb-go/identity\242\002\003CIX\252\002\021Cloudidl.Identity\312\002\021Cloudidl\\Identity\342\002\035Cloudidl\\Identity\\GPBMetadata\352\002\022Cloudidl::Identity'
  _CREATEAPPREQUEST.fields_by_name['client_name']._options = None
  _CREATEAPPREQUEST.fields_by_name['client_name']._serialized_options = b'\372B\004r\002\020\001'
  _GETAPPREQUEST.fields_by_name['client_id']._options = None
  _GETAPPREQUEST.fields_by_name['client_id']._serialized_options = b'\372B\004r\002\020\001'
  _UPDATEAPPREQUEST.fields_by_name['client_id']._options = None
  _UPDATEAPPREQUEST.fields_by_name['client_id']._serialized_options = b'\372B\004r\002\020\001'
  _DELETEAPPREQUEST.fields_by_name['client_id']._options = None
  _DELETEAPPREQUEST.fields_by_name['client_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEAPPREQUEST']._serialized_start=147
  _globals['_CREATEAPPREQUEST']._serialized_end=872
  _globals['_CREATEAPPRESPONSE']._serialized_start=874
  _globals['_CREATEAPPRESPONSE']._serialized_end=935
  _globals['_GETAPPREQUEST']._serialized_start=937
  _globals['_GETAPPREQUEST']._serialized_end=1026
  _globals['_GETAPPRESPONSE']._serialized_start=1028
  _globals['_GETAPPRESPONSE']._serialized_end=1086
  _globals['_UPDATEAPPREQUEST']._serialized_start=1089
  _globals['_UPDATEAPPREQUEST']._serialized_end=1741
  _globals['_UPDATEAPPRESPONSE']._serialized_start=1743
  _globals['_UPDATEAPPRESPONSE']._serialized_end=1804
  _globals['_DELETEAPPREQUEST']._serialized_start=1806
  _globals['_DELETEAPPREQUEST']._serialized_end=1898
  _globals['_DELETEAPPRESPONSE']._serialized_start=1900
  _globals['_DELETEAPPRESPONSE']._serialized_end=1919
  _globals['_LISTAPPSREQUEST']._serialized_start=1921
  _globals['_LISTAPPSREQUEST']._serialized_end=2030
  _globals['_LISTAPPSRESPONSE']._serialized_start=2032
  _globals['_LISTAPPSRESPONSE']._serialized_end=2116
# @@protoc_insertion_point(module_scope)
