# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: app/app_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from union.internal.app import app_payload_pb2 as app_dot_app__payload__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61pp/app_service.proto\x12\x0c\x63loudidl.app\x1a\x15\x61pp/app_payload.proto\x1a\x1cgoogle/api/annotations.proto2\xdf\n\n\nAppService\x12[\n\x06\x43reate\x12\x1b.cloudidl.app.CreateRequest\x1a\x1c.cloudidl.app.CreateResponse\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/app/api/v1:\x01*\x12\xce\x01\n\x03Get\x12\x18.cloudidl.app.GetRequest\x1a\x19.cloudidl.app.GetResponse\"\x91\x01\x90\x02\x01\x82\xd3\xe4\x93\x02\x87\x01\x12:/app/api/v1/{app_id.project}/{app_id.domain}/{app_id.name}ZI\x12G/app/api/v1/{app_id.org}/{app_id.project}/{app_id.domain}/{app_id.name}\x12\x99\x02\n\x06Update\x12\x1b.cloudidl.app.UpdateRequest\x1a\x1c.cloudidl.app.UpdateResponse\"\xd3\x01\x82\xd3\xe4\x93\x02\xcc\x01\x1aU/app/api/v1/{app.metadata.id.project}/{app.metadata.id.domain}/{app.metadata.id.name}:\x01*Zp\x1ak/app/api/v1/{app.metadata.id.org}/{app.metadata.id.project}/{app.metadata.id.domain}/{app.metadata.id.name}:\x01*\x12\xb9\x02\n\x0cUpdateStatus\x12!.cloudidl.app.UpdateStatusRequest\x1a\".cloudidl.app.UpdateStatusResponse\"\xe1\x01\x82\xd3\xe4\x93\x02\xda\x01\x1a\\/app/api/v1/status/{app.metadata.id.project}/{app.metadata.id.domain}/{app.metadata.id.name}:\x01*Zw\x1ar/app/api/v1/status/{app.metadata.id.org}/{app.metadata.id.project}/{app.metadata.id.domain}/{app.metadata.id.name}:\x01*\x12\xd4\x01\n\x06\x44\x65lete\x12\x1b.cloudidl.app.DeleteRequest\x1a\x1c.cloudidl.app.DeleteResponse\"\x8e\x01\x82\xd3\xe4\x93\x02\x87\x01*:/app/api/v1/{app_id.project}/{app_id.domain}/{app_id.name}ZI*G/app/api/v1/{app_id.org}/{app_id.project}/{app_id.domain}/{app_id.name}\x12\x65\n\x04List\x12\x19.cloudidl.app.ListRequest\x1a\x1a.cloudidl.app.ListResponse\"&\x90\x02\x01\x82\xd3\xe4\x93\x02\x1d\x12\x0b/app/api/v1Z\x0e\x12\x0c/apps/api/v1\x12G\n\x05Watch\x12\x1a.cloudidl.app.WatchRequest\x1a\x1b.cloudidl.app.WatchResponse\"\x03\x90\x02\x01\x30\x01\x12\x44\n\x05Lease\x12\x1a.cloudidl.app.LeaseRequest\x1a\x1b.cloudidl.app.LeaseResponse\"\x00\x30\x01\x42\x9e\x01\n\x10\x63om.cloudidl.appB\x0f\x41ppServiceProtoH\x02P\x01Z&github.com/unionai/cloud/gen/pb-go/app\xa2\x02\x03\x43\x41X\xaa\x02\x0c\x43loudidl.App\xca\x02\x0c\x43loudidl\\App\xe2\x02\x18\x43loudidl\\App\\GPBMetadata\xea\x02\rCloudidl::Appb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'app.app_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020com.cloudidl.appB\017AppServiceProtoH\002P\001Z&github.com/unionai/cloud/gen/pb-go/app\242\002\003CAX\252\002\014Cloudidl.App\312\002\014Cloudidl\\App\342\002\030Cloudidl\\App\\GPBMetadata\352\002\rCloudidl::App'
  _APPSERVICE.methods_by_name['Create']._options = None
  _APPSERVICE.methods_by_name['Create']._serialized_options = b'\202\323\344\223\002\020\"\013/app/api/v1:\001*'
  _APPSERVICE.methods_by_name['Get']._options = None
  _APPSERVICE.methods_by_name['Get']._serialized_options = b'\220\002\001\202\323\344\223\002\207\001\022:/app/api/v1/{app_id.project}/{app_id.domain}/{app_id.name}ZI\022G/app/api/v1/{app_id.org}/{app_id.project}/{app_id.domain}/{app_id.name}'
  _APPSERVICE.methods_by_name['Update']._options = None
  _APPSERVICE.methods_by_name['Update']._serialized_options = b'\202\323\344\223\002\314\001\032U/app/api/v1/{app.metadata.id.project}/{app.metadata.id.domain}/{app.metadata.id.name}:\001*Zp\032k/app/api/v1/{app.metadata.id.org}/{app.metadata.id.project}/{app.metadata.id.domain}/{app.metadata.id.name}:\001*'
  _APPSERVICE.methods_by_name['UpdateStatus']._options = None
  _APPSERVICE.methods_by_name['UpdateStatus']._serialized_options = b'\202\323\344\223\002\332\001\032\\/app/api/v1/status/{app.metadata.id.project}/{app.metadata.id.domain}/{app.metadata.id.name}:\001*Zw\032r/app/api/v1/status/{app.metadata.id.org}/{app.metadata.id.project}/{app.metadata.id.domain}/{app.metadata.id.name}:\001*'
  _APPSERVICE.methods_by_name['Delete']._options = None
  _APPSERVICE.methods_by_name['Delete']._serialized_options = b'\202\323\344\223\002\207\001*:/app/api/v1/{app_id.project}/{app_id.domain}/{app_id.name}ZI*G/app/api/v1/{app_id.org}/{app_id.project}/{app_id.domain}/{app_id.name}'
  _APPSERVICE.methods_by_name['List']._options = None
  _APPSERVICE.methods_by_name['List']._serialized_options = b'\220\002\001\202\323\344\223\002\035\022\013/app/api/v1Z\016\022\014/apps/api/v1'
  _APPSERVICE.methods_by_name['Watch']._options = None
  _APPSERVICE.methods_by_name['Watch']._serialized_options = b'\220\002\001'
  _globals['_APPSERVICE']._serialized_start=93
  _globals['_APPSERVICE']._serialized_end=1468
# @@protoc_insertion_point(module_scope)
